==> ejc-middlemeasurement-impl-3.0.0-20220412.090131-33-sources.jar: com/ejianc/business/middlemeasurement/vo/CreditorsrightsVO.java <==
package com.ejianc.business.middlemeasurement.vo;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.middlemeasurement.vo.CreditorsrightsdetailVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 债权情况
 * 
 * @author generator
 * 
 */
public class CreditorsrightsVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date deadline; // 截至时间 
    private java.math.BigDecimal operational; // 经营性债权
    private java.math.BigDecimal revolvingFund; // 备用金
    private java.math.BigDecimal margin; // 保证金
    private java.math.BigDecimal total; // 债权合计

    private java.lang.String sort;
    private java.lang.String billStateStr;
    
//    private List<CreditorsrightsdetailVO> creditorsrightsdetailVos = new ArrayList<>(); // 债权情况子表

    //es字段
    private java.util.Date snapShotTime; //快照保存时间
    private java.lang.String reportId; //报表ID
    private java.lang.String snapShotVersion; //快照版本

    private java.lang.String showSnapShotTime;

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }

    public Date getSnapShotTime() {
        return snapShotTime;
    }

    public void setSnapShotTime(Date snapShotTime) {
        this.snapShotTime = snapShotTime;
    }

    public String getReportId() {
        return reportId;
    }

    public void setReportId(String reportId) {
        this.reportId = reportId;
    }

    public String getSnapShotVersion() {
        return snapShotVersion;
    }

    public void setSnapShotVersion(String snapShotVersion) {
        this.snapShotVersion = snapShotVersion;
    }

    public String getShowSnapShotTime() {
        return showSnapShotTime;
    }

    public void setShowSnapShotTime(String showSnapShotTime) {
        this.showSnapShotTime = showSnapShotTime;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 截至时间 
     */
    public java.util.Date getDeadline() {
        return deadline;
    }

    /**
     * 截至时间 
     */
    public void setDeadline(java.util.Date deadline) {
        this.deadline = deadline;
    }
    /**
     * 经营性债权
     */
    public java.math.BigDecimal getOperational() {
        return operational;
    }

    /**
     * 经营性债权
     */
    public void setOperational(java.math.BigDecimal operational) {
        this.operational = operational;
    }
    /**
     * 备用金
     */
    public java.math.BigDecimal getRevolvingFund() {
        return revolvingFund;
    }

    /**
     * 备用金
     */
    public void setRevolvingFund(java.math.BigDecimal revolvingFund) {
        this.revolvingFund = revolvingFund;
    }
    /**
     * 保证金
     */
    public java.math.BigDecimal getMargin() {
        return margin;
    }

    /**
     * 保证金
     */
    public void setMargin(java.math.BigDecimal margin) {
        this.margin = margin;
    }
    /**
     * 债权合计
     */
    public java.math.BigDecimal getTotal() {
        return total;
    }

    /**
     * 债权合计
     */
    public void setTotal(java.math.BigDecimal total) {
        this.total = total;
    }
    
//     /**
//      * 债权情况子表
//      */
//     public List<CreditorsrightsdetailVO> getCreditorsrightsdetailVos() {
//        return creditorsrightsdetailVos;
//     }
//
//     /**
//      * 债权情况子表
//      */
//     public void setCreditorsrightsdetailVos(List<CreditorsrightsdetailVO> creditorsrightsdetailVos) {
//        this.creditorsrightsdetailVos = creditorsrightsdetailVos;
//     }
}

==> ejc-middlemeasurement-impl-3.0.0-20240919.082854-614-sources.jar: com/ejianc/business/middlemeasurement/vo/CreditorsrightsVO.java <==
package com.ejianc.business.middlemeasurement.vo;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.middlemeasurement.vo.CreditorsrightsdetailVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 债权情况
 * 
 * @author generator
 * 
 */
public class CreditorsrightsVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date deadline; // 截至时间 
    private java.math.BigDecimal operational; // 经营性债权
    private java.math.BigDecimal revolvingFund; // 备用金
    private java.math.BigDecimal margin; // 保证金
    private java.math.BigDecimal total; // 债权合计

    private java.lang.String sort;
    private java.lang.String billStateStr;
    
//    private List<CreditorsrightsdetailVO> creditorsrightsdetailVos = new ArrayList<>(); // 债权情况子表

    //es字段
    private java.lang.String snapShotTime; //快照保存时间
    private java.lang.String reportId; //报表ID
    private java.lang.String snapShotVersion; //快照版本

    private java.lang.String showSnapShotTime;
    private java.util.Date saveTime;

    public Date getSaveTime() {
        return saveTime;
    }

    public void setSaveTime(Date saveTime) {
        this.saveTime = saveTime;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }

    public String getSnapShotTime() {
        return snapShotTime;
    }

    public void setSnapShotTime(String snapShotTime) {
        this.snapShotTime = snapShotTime;
    }

    public String getReportId() {
        return reportId;
    }

    public void setReportId(String reportId) {
        this.reportId = reportId;
    }

    public String getSnapShotVersion() {
        return snapShotVersion;
    }

    public void setSnapShotVersion(String snapShotVersion) {
        this.snapShotVersion = snapShotVersion;
    }

    public String getShowSnapShotTime() {
        return showSnapShotTime;
    }

    public void setShowSnapShotTime(String showSnapShotTime) {
        this.showSnapShotTime = showSnapShotTime;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 截至时间 
     */
    public java.util.Date getDeadline() {
        return deadline;
    }

    /**
     * 截至时间 
     */
    public void setDeadline(java.util.Date deadline) {
        this.deadline = deadline;
    }
    /**
     * 经营性债权
     */
    public java.math.BigDecimal getOperational() {
        return operational;
    }

    /**
     * 经营性债权
     */
    public void setOperational(java.math.BigDecimal operational) {
        this.operational = operational;
    }
    /**
     * 备用金
     */
    public java.math.BigDecimal getRevolvingFund() {
        return revolvingFund;
    }

    /**
     * 备用金
     */
    public void setRevolvingFund(java.math.BigDecimal revolvingFund) {
        this.revolvingFund = revolvingFund;
    }
    /**
     * 保证金
     */
    public java.math.BigDecimal getMargin() {
        return margin;
    }

    /**
     * 保证金
     */
    public void setMargin(java.math.BigDecimal margin) {
        this.margin = margin;
    }
    /**
     * 债权合计
     */
    public java.math.BigDecimal getTotal() {
        return total;
    }

    /**
     * 债权合计
     */
    public void setTotal(java.math.BigDecimal total) {
        this.total = total;
    }
    
//     /**
//      * 债权情况子表
//      */
//     public List<CreditorsrightsdetailVO> getCreditorsrightsdetailVos() {
//        return creditorsrightsdetailVos;
//     }
//
//     /**
//      * 债权情况子表
//      */
//     public void setCreditorsrightsdetailVos(List<CreditorsrightsdetailVO> creditorsrightsdetailVos) {
//        this.creditorsrightsdetailVos = creditorsrightsdetailVos;
//     }
}
